@@ -1,4 +1,4 @@
-package Pcore::API::Whois v0.1.0;
+package Pcore::API::Whois v0.1.1;
 
 use Pcore -dist, -class;
 use Pcore::API::Whois::Server;
@@ -17,7 +17,6 @@ for my $pub_suffix ( keys $DB->{pub_suffix_server}->%* ) {
     $PUB_SUFFIX->{ P->host($pub_suffix)->name } = $DB->{pub_suffix_server}->{$pub_suffix};
 }
 
-# TODO status -> reason resolver
 sub search ( $self, $domain, $cb = undef ) {
     my $blocking_cv = defined wantarray ? AE::cv : undef;
 
@@ -44,7 +43,7 @@ sub search ( $self, $domain, $cb = undef ) {
     }
 
     if ( !$server_host ) {
-        my $res = Pcore::API::Whois::Response->new( { status => $WHOIS_NOT_SUPPORTED } );
+        my $res = Pcore::API::Whois::Response->new( { status => $WHOIS_NOT_SUPPORTED, reason => $Pcore::API::Whois::Response::STATUS_REASON->{$WHOIS_NOT_SUPPORTED} } );
 
         $cb->($res) if $cb;
 
@@ -55,7 +54,7 @@ sub search ( $self, $domain, $cb = undef ) {
             {   host => $server_host,
                 cb   => sub($server) {
                     if ( !$server || !$server->is_supported ) {
-                        my $res = Pcore::API::Whois::Response->new( { status => $WHOIS_NOT_SUPPORTED } );
+                        my $res = Pcore::API::Whois::Response->new( { status => $WHOIS_NOT_SUPPORTED, reason => $Pcore::API::Whois::Response::STATUS_REASON->{$WHOIS_NOT_SUPPORTED} } );
 
                         $cb->($res) if $cb;
 
@@ -73,7 +72,7 @@ sub search ( $self, $domain, $cb = undef ) {
                                             if ( $res->content->$* =~ $re ) {
                                                 $recognized = 1;
 
-                                                $res->set_status($WHOIS_BANNED);
+                                                $res->set_status( $WHOIS_BANNED, $Pcore::API::Whois::Response::STATUS_REASON->{$WHOIS_BANNED} );
 
                                                 last;
                                             }
@@ -85,7 +84,7 @@ sub search ( $self, $domain, $cb = undef ) {
                                             if ( $res->content->$* =~ $re ) {
                                                 $recognized = 1;
 
-                                                $res->set_status($WHOIS_NOT_FOUND);
+                                                $res->set_status( $WHOIS_NOT_FOUND, $Pcore::API::Whois::Response::STATUS_REASON->{$WHOIS_NOT_FOUND} );
 
                                                 last;
                                             }
@@ -151,11 +150,11 @@ sub export_supported_pub_suffixes ($self) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 16, 119, 136, 140    | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
+## |    3 | 16, 118, 135, 139    | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 21                   | Subroutines::ProhibitExcessComplexity - Subroutine "search" with high complexity score (27)                    |
+## |    3 | 20                   | Subroutines::ProhibitExcessComplexity - Subroutine "search" with high complexity score (27)                    |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 73, 85               | ControlStructures::ProhibitDeepNests - Code structure is deeply nested                                         |
+## |    3 | 72, 84               | ControlStructures::ProhibitDeepNests - Code structure is deeply nested                                         |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
