@@ -14,8 +14,15 @@ const our $WHOIS_BANNED        => 502;    # IP addr. is banned
 const our $WHOIS_UNKNOWN       => 503;    # unknown response type
 const our $WHOIS_NOT_SUPPORTED => 504;    # pub. suffix is not supported
 
-# TODO status => resaon hash
-# TODO stabdard API response status <=> reason resolver
+const our $STATUS_REASON => {
+    $WHOIS_FOUND         => 'Found',
+    $WHOIS_NOT_FOUND     => 'Not found',
+    $WHOIS_NETWORK_ERROR => 'Network error',
+    $WHOIS_NO_CONTENT    => 'No content',
+    $WHOIS_BANNED        => 'Banned',
+    $WHOIS_UNKNOWN       => 'Unknown',
+    $WHOIS_NOT_SUPPORTED => 'Not supported',
+};
 
 1;
 __END__
